@@ -9,7 +9,7 @@
 //   All Rights Reserved.
 //
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 #include "syastring.h"
 
